@@ -21,6 +21,7 @@
 **
 ****************************************************************************/
 #include "qtbrowserplugin.h"
+#include "qtbrowserplugin.moc"
 
 #include <QtGui>
 
@@ -29,7 +30,7 @@
 #include "qtbrowserplugin_p.h"
 
 #ifndef WINAPI
-# ifdef Q_WS_WIN
+# ifdef Q_OS_WIN
 #  define WINAPI __stdcall
 # else
 #  define WINAPI
@@ -88,7 +89,6 @@ void NPN_Version(int* plugin_major, int* plugin_minor, int* netscape_major, int*
     Q_ASSERT(qNetscapeFuncs); \
     Q_ASSERT(qNetscapeFuncs->x); \
 
-
 const char *NPN_UserAgent(NPP instance)
 {
     NPN_Prolog(uagent);
@@ -279,7 +279,6 @@ void NPN_SetException(NPObject *obj, const char *message)
     if (!This->qt.object) return false; \
     QObject *qobject = This->qt.object \
 
-
 static NPObject *NPAllocate(NPP npp, NPClass *aClass)
 {
     Q_UNUSED(npp);
@@ -762,7 +761,6 @@ int QtSignalForwarder::qt_metacall(QMetaObject::Call call, int index, void **arg
     return index;
 }
 
-
 // Plugin functions
 extern "C" NPError
 NPP_GetValue(NPP instance, NPPVariable variable, void *value)
@@ -918,7 +916,7 @@ NPP_New(NPMIMEType pluginType,
     This->fMode = mode; // NP_EMBED, NP_FULL, or NP_BACKGROUND (see npapi.h)
     This->window = 0;
     This->qt.object = 0;
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     This->rootWidget = 0;
 #endif
     This->pendingStream = 0; // stream might be created before instance
@@ -1131,7 +1129,7 @@ NPP_StreamAsFile(NPP instance, NPStream *stream, const char* fname)
         return;
 
     QString path = QString::fromLocal8Bit(fname);
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     path = "/" + path.section(':', 1).replace(':', '/');
 #endif
 
@@ -1282,7 +1280,6 @@ extern "C" NPError WINAPI NP_Shutdown()
     return NPERR_NO_ERROR;
 }
 
-
 /*!
     \class QtNPBindable qtnetscape.h
     \brief The QtNPBindable class provides an interface between a widget and the web browser.
@@ -1578,12 +1575,10 @@ void QtNPBindable::transferComplete(const QString &url, int id, Reason reason)
     Q_UNUSED(reason)
 }
 
-
 /******************************************************************************
  * The plugin itself - only one ever exists, created by QtNPFactory::create()
  *****************************************************************************/
 
-
 /*!
     \class QtNPFactory qtbrowserplugin.h
     \brief The QtNPFactory class provides the factory for plugin objects.
@@ -1639,7 +1634,6 @@ QtNPFactory::~QtNPFactory()
 {
 }
 
-
 /*!
     \fn QStringList QtNPFactory::mimeTypes() const
 
